@@ -672,7 +672,9 @@ impl App {
                 let world = resolve.select_world(&[package], None)?;
 
                 if let Some((merged_resolve, merged_world)) = &mut merged {
-                    let world = merged_resolve.merge(resolve)?.map_world(world, None)?;
+                    let world = merged_resolve
+                        .merge(resolve)?
+                        .map_world(world, Default::default())?;
                     merged_resolve.merge_worlds(world, *merged_world, &mut Default::default())?;
                 } else {
                     merged = Some((resolve, world));
